// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster;

import performancemonster.loghandler.LogMessage;
import performancemonster.loghandler.LogSender;

public class MonsterLogger
{
  private static final String ENABLED = "PerformanceMonster.LogEnabled";
  private static final String SENDER_PORT = "PerformanceMonster.Port";
  private static final String HOST_NAME = "PerformaneMonster.HostName";

  private static final LogSender sender;
  private static final boolean enabled;
  
  static {
    enabled = Boolean.parseBoolean(System.getProperty(ENABLED, "true"));
    if (enabled) {
      sender = new LogSender();
      String port = System.getProperty(SENDER_PORT);
      if (port != null) {
        sender.setPort(Integer.parseInt(port));
      }
      String host = System.getProperty(HOST_NAME);
      if (host != null) {
        sender.setRemoteHost(host);
      }
      sender.connect();
    } else {
      sender = null;
    }
  }

  public static boolean isLogEnabled()
  {
    return enabled;
  }
  
  public static void begin(String category, String message)
  {
    if (enabled) {
      LogMessage logMessage = new LogMessage(category, "BEGIN " + message);
      sender.sendLogMessage(logMessage);
    }
  }
  
  public static void end(String category, String message)
  {
    if (enabled) {
      LogMessage logMessage = new LogMessage(category, "END " + message);
      sender.sendLogMessage(logMessage);
    }
  }
}
