// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.loghandler;

import org.apache.log4j.AppenderSkeleton;
import org.apache.log4j.spi.LoggingEvent;

public class MonsterAppender extends AppenderSkeleton
{
  private final LogSender sender;

  public MonsterAppender()
  {
    sender = new LogSender();
  }

  /**
   * The <b>RemoteHost</b> option takes a string value which should be the host
   * name of the server where a
   * <code>link org.apache.log4j.net.SocketNode</code> is running.
   */
  public void setRemoteHost(String host)
  {
    sender.setRemoteHost(host);
  }

  /**
   * The <b>Port</b> option takes a positive integer representing the port
   * where the server is waiting for connections.
   */
  public void setPort(int port)
  {
    sender.setPort(port);
  }

  /**
   * Connect to the specified <b>RemoteHost</b> and <b>Port</b>.
   */
  public void activateOptions()
  {
    sender.connect();
  }

  /**
   * Close this appender.
   * <p>
   * This will mark the appender as closed and then close the log sender.
   */
  synchronized public void close()
  {
    if (closed)
      return;
    closed = true;
    sender.close();
  }

  public void append(LoggingEvent event)
  {
    if (event == null)
      return;

    LogMessage logMessage = new LogMessage(event.getLoggerName(), event
        .getRenderedMessage());
    sender.sendLogMessage(logMessage);
  }

  public void sendLogMessage(LogMessage object)
  {
    sender.sendLogMessage(object);
  }

  /**
   * MonsterAppender does not use a layout. Hence, this method returns
   * <code>false</code>.
   */
  public boolean requiresLayout()
  {
    return false;
  }
}
