// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.agent;

import java.io.IOException;
import java.lang.instrument.Instrumentation;
import java.util.StringTokenizer;

import performancemonster.agent.impl.AgentServer;
import performancemonster.helpers.SystemProperties;
import performancemonster.loghandler.LogMessage;
import performancemonster.loghandler.LogSender;

public class Agent extends Thread
{
  public static volatile LogSender sender = new LogSender();

  public static void premain(String agentArgs, Instrumentation instrumentation)
      throws IOException
  {
    System.out.println("PerformanceMonster-agent: '" + agentArgs + ", '"
        + instrumentation + "'");

    // Parse arguments
    SystemProperties properties = SystemProperties.getInstance();
    int port = properties.getAgentPortNumber();
    int logport = properties.getPortNumber();
    String logserver = properties.getLogServerHost();

    StringTokenizer tokens = new StringTokenizer(agentArgs, ",");
    while (tokens.hasMoreTokens()) {
      String nextToken = tokens.nextToken();
      int delimiter = nextToken.indexOf(':');
      if (delimiter == -1) {
        System.out.println("Invalid key-value pair: '" + nextToken + "'");
      } else {
        String key = nextToken.substring(0, delimiter);
        String value = nextToken.substring(delimiter + 1);
        System.out.println("Key: '" + key + "', value: '" + value + "'");
        if (key.equals("port")) {
          port = Integer.parseInt(value);
        } else if (key.equals("logport")) {
          logport = Integer.parseInt(value);
        } else if (key.equals("logserver")) {
          logserver = value;
        } else {
          System.out.println("Unknown key: '" + key + "' with value '" + value
              + "'");
        }
      }
    }

    sender.setPort(logport);
    sender.setRemoteHost(logserver);
    sender.connect();
    AgentServer agentServer = new AgentServer(port, instrumentation);
    agentServer.start();
  }
  
  public static void sendMessage(String text)
  {
    LogMessage logMessage = new LogMessage("default", text);
    sender.sendLogMessage(logMessage);
  }
}
