// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.agent.impl;

import java.io.*;
import java.lang.instrument.Instrumentation;
import java.net.Socket;

import performancemonster.agent.AgentCommand;

/**
 * Helper that actually processes a client connection. It receives events and
 * adds them to the supplied model.
 */
class AgentServerSlurper implements Runnable
{
  private final Socket client;
  private final Instrumentation instrumentation;

  AgentServerSlurper(Socket client, Instrumentation instrumentation)
  {
    this.client = client;
    this.instrumentation = instrumentation;
  }

  public void run()
  {
    System.out.println("Starting to get data");
    try {
      final ObjectInputStream ois = new ObjectInputStream(client
          .getInputStream());
      while (!client.isClosed()) {
        AgentCommand command = (AgentCommand) ois.readObject();
        command.execute(instrumentation);
      }
    } catch (EOFException e) {
      // LOG.info("Reached EOF, closing connection");
      e.printStackTrace();
    } catch (IOException e) {
      // LOG.warn("Got IOException, closing connection", e);
      e.printStackTrace();
    } catch (ClassNotFoundException e) {
      // TODO Auto-generated catch block
      e.printStackTrace();
    }

    try {
      client.close();
    } catch (IOException e) {
      // LOG.warn("Error closing connection", e);
    }
  }
}