// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.external;

import java.awt.Color;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.List;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;

import org.apache.log4j.Logger;

import performancemonster.external.exceptions.ExternalException;
import performancemonster.graph.coloring.ColorRule;
import performancemonster.graph.coloring.Colorer;
import performancemonster.schemas.colors.Graphcolors;
import performancemonster.schemas.colors.ObjectFactory;
import performancemonster.schemas.colors.RuleType;

public class ColorExporter
{
  private static final Logger logger = Logger.getLogger(ColorExporter.class);
  private final Colorer colorer;

  public ColorExporter(Colorer colorer)
  {
    this.colorer = colorer;
  }

  @SuppressWarnings("unchecked")
  public void exportToFile(File file) throws ExternalException
  {
    try {
      JAXBContext context = JAXBContext
          .newInstance("performancemonster.schemas.colors");
      Marshaller marshaller = context.createMarshaller();
      ObjectFactory factory = new ObjectFactory();
      Graphcolors colorTypes = factory.createGraphcolors();
      colorTypes.setBackground(convertToString(colorer.getBackgroundColor()));
      colorTypes.setDefaultBar(convertToString(colorer.getDefaultBarColor()));
      colorTypes.setDefaultBorder(convertToString(colorer.getDefaultBorderColor()));
      List ruleList = colorTypes.getRule();
      for (ColorRule rule : colorer.getColorRules()) {
        RuleType ruleType = factory.createRuleType();
        ruleType.setName(rule.getName());
        ruleType.setBar(convertToString(rule.getBarColor()));
        ruleType.setBorder(convertToString(rule.getBorderColor()));
        if (!rule.getCategory().equals("")) {
          ruleType.setCategory(rule.getCategory());
        }
        if (!rule.getMessage().equals("")) {
          ruleType.setMessage(rule.getMessage());
        }
        if (!rule.getStackTrace().equals("")) {
          ruleType.setStackTrace(rule.getStackTrace());
        }
        ruleList.add(ruleType);
      }

      marshaller.setProperty("jaxb.formatted.output", Boolean.valueOf(true));
      marshaller.marshal(colorTypes, new FileOutputStream(file));
    } catch (JAXBException e) {
      String errorString = "Could not export colors to file " + file;
      logger.error(errorString, e);
      throw new ExternalException(errorString, e);
    } catch (IOException e) {
      String errorString = "Could not export color to file " + file;
      logger.error(errorString, e);
      throw new ExternalException(errorString, e);
    }
  }
  
  private String convertToString(Color color)
  {
    int value = color.getRGB() & 0xFFFFFF;
    String s = Integer.toHexString(value).toUpperCase();
    return "#" + "000000".substring(s.length()) + s;
  }
}
