// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.external;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.util.List;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;

import org.apache.log4j.Logger;

import performancemonster.external.exceptions.ExternalException;
import performancemonster.graph.GraphElement;
import performancemonster.graph.GraphModel;
import performancemonster.schemas.graph.GraphElementType;
import performancemonster.schemas.graph.Graphelements;
import performancemonster.schemas.graph.ObjectFactory;

public class GraphExporter
{
  private static final Logger logger = Logger.getLogger(GraphExporter.class);
  private final GraphModel model;

  public GraphExporter(GraphModel model)
  {
    this.model = model;
  }

  @SuppressWarnings("unchecked")
  public void exportToFile(File file) throws ExternalException
  {
    try {
      JAXBContext context = JAXBContext
          .newInstance("performancemonster.schemas.graph");
      Marshaller marshaller = context.createMarshaller();
      ObjectFactory factory = new ObjectFactory();
      Graphelements elementTypes = factory.createGraphelements();
      List elementList = elementTypes.getGraphelement();
      for (GraphElement element : model.getElements()) {
        GraphElementType elementType = factory.createGraphElementType();
        elementType.setStartTime(BigInteger.valueOf(element.getBeginning()));
        elementType.setEndTime(BigInteger.valueOf(element.getEnd()));
        elementType.setCategory(element.getCategory());
        elementType.setMessage(element.getMessage());
        elementType.setStackTrace(element.getStackTrace());
        elementList.add(elementType);
      }

      marshaller.setProperty("jaxb.formatted.output", Boolean.valueOf(true));
      marshaller.marshal(elementTypes, new FileOutputStream(file));
    } catch (JAXBException e) {
      String errorString = "Could not export data to file " + file;
      logger.error(errorString, e);
      throw new ExternalException(errorString, e);
    } catch (IOException e) {
      String errorString = "Could not export data to file " + file;
      logger.error(errorString, e);
      throw new ExternalException(errorString, e);
    }
  }
}
