// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.external;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;

import org.apache.log4j.Logger;

import performancemonster.analyzer.impl.GraphElementIdCreator;
import performancemonster.external.exceptions.ExternalException;
import performancemonster.graph.GraphElement;
import performancemonster.graph.GraphModel;
import performancemonster.schemas.graph.GraphElementType;
import performancemonster.schemas.graph.Graphelements;

public class GraphImporter
{
  private static final Logger logger = Logger.getLogger(GraphImporter.class);

  private final GraphModel model;

  public GraphImporter(GraphModel model)
  {
    this.model = model;
  }

  public void importFromFile(File file) throws ExternalException
  {
    try {
      JAXBContext context = JAXBContext
          .newInstance("performancemonster.schemas.graph");
      Unmarshaller unmarshaller = context.createUnmarshaller();

      Graphelements graphElements = (Graphelements) unmarshaller
          .unmarshal(new FileInputStream(file));

      // Clear the existing model
      model.clear();

      for (Object o : graphElements.getGraphelement()) {
        GraphElementType elementType = (GraphElementType) o;
        model.putElement(createGraphElement(elementType.getCategory(),
            elementType.getMessage(), elementType.getStackTrace(), elementType
                .getStartTime().longValue(), elementType.getEndTime()
                .longValue()));
      }
    } catch (JAXBException e) {
      String errorString = "Could not import data from file " + file;
      logger.error(errorString, e);
      throw new ExternalException(errorString, e);
    } catch (FileNotFoundException e) {
      String errorString = "Could not import data from file " + file;
      logger.error(errorString, e);
      throw new ExternalException(errorString, e);
    }
  }

  private GraphElement createGraphElement(final String category,
      final String message, final String stackTrace, final long beginning,
      final long end)
  {
    return new GraphElement()
    {
      private final long id = GraphElementIdCreator.createNewId();
      
      public String getCategory()
      {
        return category;
      }

      public String getMessage()
      {
        return message;
      }

      public String getStackTrace()
      {
        return stackTrace;
      }
      
      public boolean isEnded()
      {
        return true;
      }

      public long getBeginning()
      {
        return beginning;
      }

      public long getEnd()
      {
        return end;
      }

      public long getId()
      {
        return id;
      }
    };
  }
}
