// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.graph;

import java.util.Collections;
import java.util.Comparator;
import java.util.Set;
import java.util.SortedSet;
import java.util.TreeSet;

public class GraphModel
{
  private static final Comparator<GraphElement> comparator = new GraphElementComparator();
  private final SortedSet<GraphElement> elements;
  
  public GraphModel()
  {
    elements = new TreeSet<GraphElement>(comparator);
  }
  
  public synchronized void clear()
  {
    elements.clear();
  }
  
  public synchronized void removeElement(GraphElement element)
  {
    elements.remove(element);
  }
  
  public synchronized void putElement(GraphElement element)
  {
    elements.add(element);
  }
    
  public synchronized Set<GraphElement> getElements()
  {
    return Collections.unmodifiableSet(elements);
  }
  
  private static class GraphElementComparator implements Comparator<GraphElement>
  {
    public int compare(GraphElement e1, GraphElement e2)
    {
      long beginDiff = e1.getBeginning() - e2.getBeginning();
      if (beginDiff > 0) {
        return 1;
      } else if (beginDiff < 0) {
        return -1;
      }
      
      if (e1.isEnded() && e2.isEnded()) {
        long endDiff = e1.getEnd() - e2.getEnd();
        if (endDiff > 0) {
          return -1;
        } else if (endDiff < 0) {
          return 1;
        }
      } else if (e1.isEnded() && !e2.isEnded()) {
        return 1;
      } else if (!e1.isEnded() && e2.isEnded()) {
        return -1;
      }

      int messageDiff = e1.getMessage().compareTo(e2.getMessage());
      if (messageDiff != 0) {
        return messageDiff;
      }

      int stackTraceDiff = e1.getStackTrace().compareTo(e2.getStackTrace());
      if (stackTraceDiff !=0) {
        return stackTraceDiff;
      }
      
      long idDiff = e1.getId() - e2.getId();
      if (idDiff > 0) {
        return 1;
      } else if (idDiff < 0) {
        return -1;
      }
      
      return 0;
    }
  }
}
