// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.helpers;

import java.util.Enumeration;
import java.util.Iterator;

/**
 * Helper class, turns an {@link java.util.Iterator} into an
 * {@link java.util.Enumeration}, which is unfortunately required in some Swing
 * code.
 */
public class EnumerationAdapter implements Enumeration
{
  private final Iterator it;

  /**
   * Wraps an {@link Iterator} into an {@link Enumeration}.
   * 
   * @param it
   *          The {@link Iterator} to wrap.
   */
  public EnumerationAdapter(Iterator it)
  {
    this.it = it;
  }

  /**
   * @see Enumeration#hasMoreElements()
   */
  public boolean hasMoreElements()
  {
    return it.hasNext();
  }

  /**
   * @see Enumeration#nextElement()
   */
  public Object nextElement()
  {
    return it.next();
  }
}
