// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.instrumentation.impl;

import java.io.Serializable;
import java.lang.instrument.Instrumentation;
import java.lang.instrument.UnmodifiableClassException;
import java.util.*;

import org.apache.log4j.Logger;

import performancemonster.agent.AgentCommand;
import performancemonster.instrumentation.ClassDefinition;

public class TransformCommand implements AgentCommand, Serializable
{
  private final static Logger logger = Logger.getLogger(TransformCommand.class);
  
  private final Set<InstrumentedClass> instrumentedClasses;

  public TransformCommand()
  {
    instrumentedClasses = new HashSet<InstrumentedClass>();
  }

  public void addInstrumentation(ClassDefinition classDefinition,
      byte[] bytecode)
  {
    InstrumentedClass instrumentation = new InstrumentedClass(classDefinition
        .getFullName(), bytecode);
    instrumentedClasses.add(instrumentation);
  }

  public void execute(Instrumentation inst)
  {
    logger.debug("TransformCommand.execute");
    ClassLoader classLoader = this.getClass().getClassLoader();
    try {
      java.lang.instrument.ClassDefinition[] definitions = new java.lang.instrument.ClassDefinition[instrumentedClasses
          .size()];
      int i = 0;
      for (InstrumentedClass instrumentation : instrumentedClasses) {
        definitions[i++] = new java.lang.instrument.ClassDefinition(classLoader
            .loadClass(instrumentation.getClassName()), instrumentation
            .getBytecode());
      }
      inst.redefineClasses(definitions);
    } catch (ClassNotFoundException e) {
      // TODO Auto-generated catch block
      e.printStackTrace();
    } catch (UnmodifiableClassException e) {
      // TODO Auto-generated catch block
      e.printStackTrace();
    }
    logger.debug("TransformCommand.execute done");
  }
  
  public String toString()
  {
    return "TransformCommand[" + instrumentedClasses + "]";
  }

  private static class InstrumentedClass implements Serializable
  {
    private final String className;
    private final byte[] bytecode;

    public InstrumentedClass(String className, byte[] bytecode)
    {
      this.className = className;
      this.bytecode = bytecode;
    }

    public String getClassName()
    {
      return className;
    }

    public byte[] getBytecode()
    {
      return bytecode;
    }
  }
}
