// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.instrumentation.impl.transform;

import org.objectweb.asm.*;

class InstrumentMethodVisitor extends MethodAdapter
{
  private final Label labelBegin;
  private final MethodVisitor mv;
  private final String instrumentationText;

  public InstrumentMethodVisitor(MethodVisitor mv, String instrumentationText)
  {
    super(mv);
    this.mv = mv;
    this.labelBegin = new Label();
    this.instrumentationText = instrumentationText;

    insertDebugBegin();
  }

  public void visitInsn(int opcode)
  {
    switch (opcode) {
    case org.objectweb.asm.Opcodes.IRETURN:
      // Fall through
    case org.objectweb.asm.Opcodes.LRETURN:
      // Fall through
    case org.objectweb.asm.Opcodes.FRETURN:
      // Fall through
    case org.objectweb.asm.Opcodes.DRETURN:
      // Fall through
    case org.objectweb.asm.Opcodes.ARETURN:
      // Fall through
    case org.objectweb.asm.Opcodes.RETURN:
      insertDebugAfter();
      break;
    default:
      break;
    }
    mv.visitInsn(opcode);
  }

  public void visitEnd()
  {
    Label labelEnd = new Label();
    visitLabel(labelEnd);
    mv.visitIntInsn(org.objectweb.asm.Opcodes.ASTORE, 0);
    insertDebugAfter();
    mv.visitIntInsn(Opcodes.ALOAD, 0);
    mv.visitInsn(org.objectweb.asm.Opcodes.ATHROW);
    mv.visitTryCatchBlock(labelBegin, labelEnd, labelEnd, null);
  }

  // "Real-life" implementation
  private void insertDebugBegin()
  {
    mv.visitLdcInsn("BEGIN " + instrumentationText);
    mv.visitMethodInsn(org.objectweb.asm.Opcodes.INVOKESTATIC, "performancemonster/agent/Agent", "sendMessage", "(Ljava/lang/String;)V");
    mv.visitLabel(labelBegin);
  }

  // "Real-life" implementation
  private void insertDebugAfter()
  {
    mv.visitLdcInsn("END " + instrumentationText);
    mv.visitMethodInsn(org.objectweb.asm.Opcodes.INVOKESTATIC,
        "performancemonster/agent/Agent", "sendMessage",
        "(Ljava/lang/String;)V");
  }

  // Debug implementation of the debug methods
  /*private void insertDebugAfter()
  {
    mv.visitFieldInsn(org.objectweb.asm.Opcodes.GETSTATIC,
        "java/lang/System", "out", "Ljava/io/PrintStream;");
    mv.visitLdcInsn("END " + instrumentationText);
    mv.visitMethodInsn(org.objectweb.asm.Opcodes.INVOKEVIRTUAL,
        "java/io/PrintStream", "println", "(Ljava/lang/String;)V");
  }

  private void insertDebugBegin()
  {
    mv.visitFieldInsn(org.objectweb.asm.Opcodes.GETSTATIC,
        "java/lang/System", "out", "Ljava/io/PrintStream;");
    mv.visitLdcInsn("BEGIN " + instrumentationText);
    mv.visitMethodInsn(org.objectweb.asm.Opcodes.INVOKEVIRTUAL,
        "java/io/PrintStream", "println", "(Ljava/lang/String;)V");
    mv.visitLabel(labelBegin);
  }*/
}