// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.instrumentation.impl.transform;

import java.io.*;
import java.util.HashSet;
import java.util.Set;

import org.objectweb.asm.ClassReader;
import org.objectweb.asm.ClassWriter;

import performancemonster.instrumentation.ClassDefinition;
import performancemonster.instrumentation.MethodDefinition;

/**
 * Using the ASM framework, instruments certain methods in certain classes with
 * performance monitoring at method entry and method exit.
 */
public class Transform
{
  private static final String filename = "test/performancemonster/MinTest.class";

  static final String methodname = "hej2";

  public static void main(String[] args) throws IOException
  {
    InputStream stream = new FileInputStream(filename);
    ClassReader classReader = new ClassReader(stream);

    ClassWriter classWriter = new ClassWriter(true);
    Set<String> methodnames = new HashSet<String>();
    methodnames.add(methodname);
    InstrumentClassVisitor classVisitor = new InstrumentClassVisitor(
        classWriter, methodnames);
    classReader.accept(classVisitor, true);

    byte[] bytecodes = classWriter.toByteArray();
    OutputStream outputStream = new FileOutputStream(filename);
    outputStream.write(bytecodes);
    outputStream.close();
  }

  /**
   * Instruments a single method, returns the bytes of the modified class
   * definition.
   */
  public static byte[] transformMethod(MethodDefinition method)
  {
    Set<MethodDefinition> methods = new HashSet<MethodDefinition>();
    methods.add(method);
    return transformMethods(methods);
  }

  /**
   * Instruments the given methods. All the methods must belong to the same
   * {@link ClassDefinition}.
   * 
   * @param methods
   *          The methods to instrument.
   * @return The transformed bytecodes of the class.
   */
  public static byte[] transformMethods(Set<MethodDefinition> methods)
  {
    if (methods.isEmpty()) {
      throw new IllegalArgumentException("Set of methods is empty");
    }

    ClassDefinition classDefinition = methods.iterator().next().getClassDefinition();
    ClassReader classReader = new ClassReader(classDefinition.getBytes());
    ClassWriter classWriter = new ClassWriter(true);

    Set<String> methodnames = new HashSet<String>();
    for (MethodDefinition method : methods) {
      methodnames.add(method.getName());
    }

    InstrumentClassVisitor classVisitor = new InstrumentClassVisitor(
        classWriter, methodnames);
    classReader.accept(classVisitor, false);

    return classWriter.toByteArray();
  }
}
