package performancemonster.presentation.colors.impl;

import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JColorChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.border.LineBorder;

import performancemonster.graph.coloring.ColorChangeListener;

/**
 * Displays a colored label and a button containing "...". By clicking on the
 * button, you get a {@link javax.swing.JColorChooser} where you can choose the
 * color of the label. When a new color has been chosen a
 * {@link performancemonster.presentation.colors.impl.ColorAccessor} is invoked.
 */
public class ColorChooserButton extends JPanel implements ColorChangeListener
{
  private final JLabel label;
  private final ColorAccessor colorAccessor;
  
  /**
   * Creates a new ColorChooserButton.
   * 
   * @param titleText
   *          The title text of the {@link JColorChooser}.
   * @param colorAccessor
   *          The {@link ColorAccessor} used when a new color is chosen.
   */
  public ColorChooserButton(final String titleText,
      final ColorAccessor colorAccessor)
  {
    this.colorAccessor = colorAccessor;

    label = new JLabel("    ");
    label.setOpaque(true);
    label.setBorder(new LineBorder(Color.BLACK));
    label.setBackground(colorAccessor.getColor());

    final JButton button = new JButton("...");
    button.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      {
        Color c = JColorChooser.showDialog(button, titleText, label
            .getBackground());
        if (c != null) {
          colorAccessor.setColor(c);
        }
      }
    });

    setLayout(new FlowLayout(FlowLayout.LEFT));
    add(label);
    add(button);
  }
  
  public void coloringChanged()
  {
    label.setBackground(colorAccessor.getColor());
    label.setForeground(colorAccessor.getColor());
  }

  public void setCurrentColor(Color c)
  {
    label.setBackground(c);
    label.setForeground(c);
  }
}
