// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.presentation.colors.impl;

import javax.swing.table.AbstractTableModel;

import performancemonster.graph.coloring.ColorChangeListener;
import performancemonster.graph.coloring.ColorRule;
import performancemonster.graph.coloring.Colorer;

public class ColorRuleTableModel extends AbstractTableModel
{
  private static final String[] columnNames = { "Name", "Bar", "Border" };
  private final Colorer colorer;

  public ColorRuleTableModel(Colorer colorer)
  {
    this.colorer = colorer;
    colorer.addChangeListener(new ColorChangeListener()
    {
      public void coloringChanged()
      {
        fireTableDataChanged();
      }
    });
  }

  public int getColumnCount()
  {
    return columnNames.length;
  }

  public int getRowCount()
  {
    return colorer.getNumberOfRules();
  }

  public String getColumnName(int col)
  {
    return columnNames[col];
  }

  public Object getValueAt(int row, int col)
  {
    ColorRule rule = colorer.getColorRule(row);
    if (col == 0) {
      return rule.getName();
    } else if (col == 1) {
      return rule.getBarColor();
    } else if (col == 2) {
      return rule.getBorderColor();
    } else {
      throw new IllegalArgumentException("No value at position (" + row + ","
          + col + ")");
    }
  }

  public Class<?> getColumnClass(int c)
  {
    return getValueAt(0, c).getClass();
  }
}