// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.presentation.helpers;

import java.awt.*;

import javax.swing.JPanel;

public class LayoutManagerHandler
{
  public static enum Direction
  {
    HORIZONTAL, VERTICAL
  }

  public static enum Resize
  {
    HORIZONTAL, VERTICAL, BOTH
  }

  private final Direction direction;
  private final GridBagLayout gridbag;
  private final GridBagConstraints constraints;
  private final JPanel panel;

  public LayoutManagerHandler(Direction direction)
  {
    this.direction = direction;
    gridbag = new GridBagLayout();
    constraints = new GridBagConstraints();
    constraints.insets = new Insets(2, 2, 2, 2);
    switch (direction) {
    case HORIZONTAL:
      constraints.weighty = 1.0;
      constraints.gridheight = GridBagConstraints.REMAINDER;
      break;
    case VERTICAL:
      constraints.weightx = 1.0;
      constraints.gridwidth = GridBagConstraints.REMAINDER;
      break;
    default:
      throw new IllegalStateException("Unknown direction: " + direction);
    }
    panel = new JPanel(gridbag);
  }

  public void addComponent(Component component, boolean resize, double weight)
  {
    if (resize) {
      constraints.fill = GridBagConstraints.BOTH;
    } else {
      switch (direction) {
      case HORIZONTAL:
        constraints.fill = GridBagConstraints.VERTICAL;
        break;
      case VERTICAL:
        constraints.fill = GridBagConstraints.HORIZONTAL;
        break;
      default:
        throw new IllegalStateException("Unknown direction: " + direction);
      }
    }

    switch (direction) {
    case HORIZONTAL:
      constraints.weightx = weight;
      break;
    case VERTICAL:
      constraints.weighty = weight;
      break;
    default:
      throw new IllegalStateException("Unknown direction: " + direction);
    }
    
    panel.add(component, constraints.clone());
  }

  public void addLineSeparator()
  {
    switch (direction) {
    case HORIZONTAL:
      constraints.gridy++;
      break;
    case VERTICAL:
      constraints.gridx++;
      break;
    default:
      throw new IllegalStateException("Unknown direction: " + direction);
    }
  }

  public JPanel getPanel()
  {
    return panel;
  }
}
