// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.presentation.helpers;

import java.util.*;
import java.util.Collection;
import java.util.List;

import javax.swing.ListModel;
import javax.swing.event.ListDataEvent;
import javax.swing.event.ListDataListener;

public class MyListModel<E> implements ListModel
{
  protected final List<E> elements;
  private final Collection<ListDataListener> listeners;

  protected MyListModel()
  {
    elements = new ArrayList<E>();
    listeners = new HashSet<ListDataListener>();
  }

  public int getSize()
  {
    return elements.size();
  }

  public E getElementAt(int index)
  {
    return elements.get(index);
  }

  public void addListDataListener(ListDataListener l)
  {
    listeners.add(l);
  }

  public void removeListDataListener(ListDataListener l)
  {
    listeners.remove(l);
  }

  protected void substituteList(List<E> newList)
  {
    int oldSize = getSize();
    int newSize = newList.size();
    elements.clear();
    elements.addAll(newList);
    notifyListeners(Math.max(oldSize, newSize));
  }

  private void notifyListeners(int maxSize)
  {
    ListDataEvent event = new ListDataEvent(this,
        ListDataEvent.CONTENTS_CHANGED, 0, maxSize);
    for (ListDataListener listener : listeners) {
      listener.contentsChanged(event);
    }
  }
}
