// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.presentation.instrumentation.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.Set;

import performancemonster.instrumentation.settings.Setting;
import performancemonster.presentation.helpers.MyListModel;

public class InstrumentedListModel extends MyListModel<Setting>
{
  private final List<Setting> instrumentationSettings;

  public InstrumentedListModel()
  {
    instrumentationSettings = new ArrayList<Setting>();
  }
  
  public boolean contains(Setting setting)
  {
    return instrumentationSettings.contains(setting);
  }

  public void addSettings(Set<Setting> settings)
  {
    for (Setting setting : settings) {
      if (!instrumentationSettings.contains(setting)) {
        instrumentationSettings.add(setting);
      }
    }
    sortList();
    substituteList(instrumentationSettings);
  }

  public void removeSettings(Set<Setting> settings)
  {
    instrumentationSettings.removeAll(settings);
    sortList();
    substituteList(instrumentationSettings);
  }

  private void sortList()
  {
    Collections.sort(instrumentationSettings, new Comparator<Setting>()
    {
      public int compare(Setting s1, Setting s2)
      {
        return s1.toString().compareTo(s2.toString());
      }
    });
  }
}
