// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.presentation.instrumentation.impl;

import java.util.ArrayList;
import java.util.Enumeration;
import java.util.List;

import javax.swing.tree.TreeNode;

import performancemonster.helpers.EnumerationAdapter;

public class PackageTreeNode implements TreeNode
{
  private final List<TreeNode> children = new ArrayList<TreeNode>();
  private final PackageTreeNode parent;
  private final String subPackage;
  private final String fullPackage;

  public PackageTreeNode(PackageTreeNode parent, String subPackage)
  {
    this.parent = parent;
    this.subPackage = subPackage;
    fullPackage = getFullPackageName();
  }

  public TreeNode getChildAt(int childIndex)
  {
    return children.get(childIndex);
  }

  public int getChildCount()
  {
    return children.size();
  }

  public TreeNode getParent()
  {
    return parent;
  }

  public int getIndex(TreeNode node)
  {
    return children.indexOf(node);
  }

  public boolean getAllowsChildren()
  {
    return true;
  }

  public boolean isLeaf()
  {
    return false;
  }

  public Enumeration children()
  {
    return new EnumerationAdapter(children.iterator());
  }
  
  public void addChild(PackageTreeNode child)
  {
    children.add(child);
  }

  public void addChild(ClassTreeNode child)
  {
    children.add(child);
  }
  
  public String getPackageName()
  {
    return fullPackage;
  }
  
  public String getSubPackageName()
  {
    return subPackage;
  }

  public String toString()
  {
    return subPackage;
  }
  
  protected void clearChildren()
  {
    children.clear();
  }

  private String getFullPackageName()
  {
    if (parent instanceof PackageRootNode || parent == null) {
      return subPackage;
    } else {
      return parent.getFullPackageName() + '.' + subPackage;
    }
  }
}
