// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.documentation;

import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JFrame;

import junit.extensions.jfcunit.JFCTestCase;
import junit.extensions.jfcunit.JFCTestHelper;
import junit.extensions.jfcunit.TestHelper;
import junit.extensions.jfcunit.eventdata.MouseEventData;
import junit.extensions.jfcunit.finder.NamedComponentFinder;
import performancemonster.graph.GraphModel;
import performancemonster.helpers.MockFactory;
import performancemonster.presentation.overview.MonsterGUI;

public class QuickTest extends JFCTestCase
{
  public QuickTest(String name)
  {
    super(name);
  }

  protected void setUp() throws Exception
  {
    super.setUp();
    setHelper(new JFCTestHelper());
  }

  protected void tearDown() throws Exception
  {
    TestHelper.cleanUp(this);
    super.tearDown();
  }

  public void testEmptyMainWindow() throws Exception
  {
    GraphModel model = new GraphModel();
    MonsterGUI gui = new MonsterGUI(model);
    gui.createAndShowGUI();
    JFrame mainWindow = gui.getJFrame();
    WindowGrabber.grabFrame(mainWindow, "doc/screengrabs/EmptyMainWindow.png");
    TestHelper.disposeWindow(mainWindow, this);
  }

  public void testSimpleMainWindow() throws Exception
  {
    GraphModel model = new GraphModel();
    model.putElement(MockFactory.createGraphElement("C1", "M1", "S1", 10, 100));
    model.putElement(MockFactory.createGraphElement("C1", "M2", "S2", 10, 20));
    model.putElement(MockFactory.createGraphElement("C1", "M3", "S3", 20, 30));
    model.putElement(MockFactory.createGraphElement("C1", "M4", "S4", 30, 40));
    model.putElement(MockFactory.createGraphElement("C1", "M5", "S5", 40, 50));
    model.putElement(MockFactory.createGraphElement("C1", "M6", "S6", 50, 60));
    model.putElement(MockFactory.createGraphElement("C1", "M7", "S7", 60, 70));
    model.putElement(MockFactory.createGraphElement("C1", "M8", "S8", 70, 80));
    model.putElement(MockFactory.createGraphElement("C1", "M9", "S9", 80, 90));
    model.putElement(MockFactory
        .createGraphElement("C1", "M20", "S10", 90, 100));
    MonsterGUI gui = new MonsterGUI(model);
    gui.createAndShowGUI();
    JFrame mainWindow = gui.getJFrame();

    // Make sure the GUI is updated
    gui.update();
    NamedComponentFinder finder = new NamedComponentFinder(JComponent.class,
        "AlignButton");
    JButton alignButton = (JButton) finder.find(mainWindow, 0);
    assertNotNull("Could not find the Align button", alignButton);
    getHelper().enterClickAndLeave(new MouseEventData(this, alignButton));

    WindowGrabber.grabFrame(mainWindow, "doc/screengrabs/SimpleMainWindow.png");
    TestHelper.disposeWindow(mainWindow, this);
  }
}
