// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.test.external;

import java.io.File;

import junit.framework.TestCase;
import performancemonster.external.GraphImporter;
import performancemonster.graph.GraphElement;
import performancemonster.graph.GraphModel;

/**
 * Tests {@link GraphImporter}. Does so by reading files generated by running
 * {@link GraphExportTest}.
 */
public class GraphImportTest extends TestCase
{
  /**
   * Imports an empty model.
   */
  public void testGraphImportNoElements() throws Exception
  {
    File file = new File("test/GraphImportTest_NoElements.xml");
    GraphModel model = new GraphModel();
    GraphImporter importer = new GraphImporter(model);
    importer.importFromFile(file);

    assertEquals("Wrong number of elements in loaded model", 0, model
        .getElements().size());
  }

  /**
   * Imports a model with only one element, checks that all attributes of that
   * element are correctly imported.
   */
  public void testGraphImportOneElement() throws Exception
  {
    File file = new File("test/GraphImportTest_OneElement.xml");
    GraphModel model = new GraphModel();
    GraphImporter importer = new GraphImporter(model);
    importer.importFromFile(file);

    assertEquals("Wrong number of elements in the list", 1, model.getElements()
        .size());
    GraphElement element = model.getElements().iterator().next();
    assertGraphElement(element, "Message1", "StackTrace1", 10, 20);
  }

  /**
   * Imports a model with a single element which has as many of its attributes
   * as possible "blanked out".
   */
  public void testGraphImportElementMissingInformation() throws Exception
  {
    File file = new File("test/GraphImportTest_ElementMissingInformation.xml");
    GraphModel model = new GraphModel();
    GraphImporter importer = new GraphImporter(model);
    importer.importFromFile(file);

    assertEquals("Wrong number of elements in the list", 1, model.getElements()
        .size());
    GraphElement element = model.getElements().iterator().next();
    assertGraphElement(element, "", null, 0, 0);
  }

  /**
   * Imports a model with 5 elements. Only checks that 5 elements are imported,
   * not that the contents are correct.
   */
  public void testGraphImportMoreElements() throws Exception
  {
    File file = new File("test/GraphImportTest_MoreElements.xml");
    GraphModel model = new GraphModel();
    GraphImporter importer = new GraphImporter(model);
    importer.importFromFile(file);

    assertEquals("Wrong number of elements in the list", 5, model.getElements()
        .size());
  }

  private void assertGraphElement(GraphElement element, String message,
      String stackTrace, long begin, long end)
  {
    assertEquals("Message incorrect", message, element.getMessage());
    assertEquals("Stack trace incorrect", stackTrace, element.getStackTrace());
    assertEquals("Begin time incorrect", begin, element.getBeginning());
    assertEquals("End time incorrect", end, element.getEnd());
  }
}
