// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.test.instrumentation;

import java.util.Collection;
import java.util.List;

import junit.framework.TestCase;
import performancemonster.instrumentation.ClassDefinition;
import performancemonster.instrumentation.MethodDefinition;
import performancemonster.instrumentation.impl.DirectoryFileClassDefinition;

public class DirectoryFileClassDefinitionTest extends TestCase
{
  public static final String DIRECTORY = "release/test/classes";
  public static final String FAKEDIRECTORY = "release/XYZ"; 
  public static final String INSPECTEDCLASS = "release/test/misc/ClassToInspect.class";

  public void testLoadDirectory()
  {
    Collection<ClassDefinition> loadedClasses = DirectoryFileClassDefinition
        .analyzeDirectory(DIRECTORY);
    assertTrue("No classes could be loaded", loadedClasses.size() > 0);
  }
  
  public void testLoadFailsWithWrongDirectoryName()
  {
    Collection<ClassDefinition> loadedClasses = DirectoryFileClassDefinition
        .analyzeDirectory(FAKEDIRECTORY);
    assertEquals("No classes should be loaded", 0, loadedClasses.size());
  }
  
  public void testInspectClass()
  {
    Collection<ClassDefinition> loadedClasses = DirectoryFileClassDefinition
        .analyzeDirectory(DIRECTORY);
    ClassDefinition classToInspect = null;
    for (ClassDefinition definition : loadedClasses) {
      if (definition.getFullName().equals(
          "performancemonster.test.instrumentation.ClassToInspect")) {
        classToInspect = definition;
      }
    }
    
    assertNotNull("Did not find ClassToInspect", classToInspect);
    assertEquals("Wrong package name",
        "performancemonster.test.instrumentation", classToInspect
            .getPackageName());
    assertEquals("Wrong short class name", "ClassToInspect", classToInspect
        .getShortName());
    assertTrue("Wrong contents", new FileToBytesComparator(INSPECTEDCLASS)
        .compareToArray(classToInspect.getBytes()));
    List<MethodDefinition> methods = classToInspect.getMethods();
    assertEquals("Wrong number of methods", 3, methods.size());
    assertEquals("Wrong name of first method", "<init>", methods.get(0).getName());
    assertEquals("Wrong name of second method", "method1", methods.get(1).getName());
    assertEquals("Wrong name of third method", "method2", methods.get(2).getName());
  }
}
