// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.test.instrumentation;

import java.io.FileInputStream;
import java.io.IOException;

public class FileToBytesComparator
{
  private final byte[] bytes;
  
  public FileToBytesComparator(String fileName)
  {
    try {
      FileInputStream fileInputStream = new FileInputStream(fileName);
      byte[] result = new byte[0];
      byte[] buffer = new byte[1024];
      for (int readBytes = fileInputStream.read(buffer, 0, 1024); readBytes != -1; readBytes = fileInputStream
          .read(buffer, 0, 1024)) {
        byte[] newResult = new byte[result.length + readBytes];
        System.arraycopy(result, 0, newResult, 0, result.length);
        System.arraycopy(buffer, 0, newResult, result.length, readBytes);
        result = newResult;
      }
      bytes = result;
    } catch (IOException e) {
      throw new IllegalStateException("Could not read file", e);
    }
  }
  
  public boolean compareToArray(byte[] other)
  {
    if (bytes.length != other.length) {
      System.out.println("Different lengths: " + bytes.length + " != "
          + other.length);
      return false;
    }
    for (int i = 0; i < bytes.length; i++) {
      if (bytes[i] != other[i]) {
        System.out.println("At position " + i + ": " + bytes[i] + " != "
            + other[i]);
        return false;
      }
    }
    return true;
  }
}
