// PerformanceMonster
// Copyright (C) 2005  Ole Friis <olefriis@gmail.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package performancemonster.test.stress;

import junit.framework.TestCase;
import performancemonster.MonsterLogger;
import performancemonster.analyzer.LogAnalyzer;
import performancemonster.graph.GraphModel;
import performancemonster.loghandler.LogServer;

public class LogServerAndAnalyzerStressTest extends TestCase
{
  private static final int THREADS = 100;
  private static final int MESSAGES_PER_THREAD = 100;
  private static final int SERVERPORT = 4560;
  private LogServer server;
  private GraphModel model;
  private LogAnalyzer logAnalyzer;
  private volatile int numberOfFinishedThreads;
  
  @Override
  protected void setUp() throws Exception
  {
    server = new LogServer(SERVERPORT);
    model = new GraphModel();
    logAnalyzer = new LogAnalyzer(model);
    server.addLogListener(logAnalyzer);
    server.start();
  }

  @Override
  protected void tearDown() throws Exception
  {
    server.stopServer();
  }
  
  public synchronized void finished()
  {
    numberOfFinishedThreads++;
  }
  
  /**
   * Let 100 threads bang away, sending 100 log pairs each.
   */
  public void testLogServer_manual() throws Exception
  {
    for (int i = 0; i < THREADS; i++) {
      Runnable r = new Runnable()
      {
        public void run()
        {
          for (int i = 0; i < MESSAGES_PER_THREAD; i++) {
            MonsterLogger.begin("MyCategory", "My message");
            MonsterLogger.end("MyCategory", "My message");
          }
          finished();
        }
      };
      new Thread(r).start();
    }
    
    while (numberOfFinishedThreads < THREADS) {
      try {
        Thread.sleep(1000);
      } catch (InterruptedException e) {
        // Ignore
      }
    }
    
    Thread.sleep(1000);
    assertEquals("Incorrect number of log messages", THREADS
        * MESSAGES_PER_THREAD, model.getElements().size());
  }
}
